@@ -240,9 +240,9 @@ void App_WithDoc_Gtk::ui_warning(const Glib::ustring& text, const Glib::ustring&
   GtkDialogs::ui_warning(*this, text, secondary_text);
 }
 
-Glib::ustring App_WithDoc_Gtk::ui_file_select_open()
+Glib::ustring App_WithDoc_Gtk::ui_file_select_open(const Glib::ustring& starting_folder_uri)
 {
-  return GtkDialogs::ui_file_select_open(*this);
+  return GtkDialogs::ui_file_select_open(*this, starting_folder_uri);
 }
 
 Glib::ustring App_WithDoc_Gtk::ui_file_select_save(const Glib::ustring& old_file_uri)
